<?php
/*
 * Plugin name: Grimlock for WooCommerce
 * Plugin URI:  http://www.themosaurus.com
 * Description: Adds integration features for Grimlock and WooCommerce.
 * Author:      Themosaurus
 * Author URI:  http://www.themosaurus.com
 * Version:     1.4.5
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * WC requires at least: 6.0
 * WC tested up to: 6.6.1
 * Text Domain: grimlock-woocommerce
 * Domain Path: /languages
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

define( 'GRIMLOCK_WOOCOMMERCE_VERSION',              '1.4.5' );
define( 'GRIMLOCK_WOOCOMMERCE_MIN_GRIMLOCK_VERSION', '1.5.5' );
define( 'GRIMLOCK_WOOCOMMERCE_PLUGIN_FILE',     __FILE__ );
define( 'GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH', plugin_dir_path( __FILE__ ) );
define( 'GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_URL',  plugin_dir_url( __FILE__ ) );

// Initialize update checker
require 'libs/plugin-update-checker/plugin-update-checker.php';
Puc_v4_Factory::buildUpdateChecker(
	'http://files.themosaurus.com/grimlock-woocommerce/version.json',
	__FILE__,
	'grimlock-woocommerce'
);

/**
 * Display notice if Grimlock version doesn't match minimum requirement
 */
function grimlock_woocommerce_dependency_notice() {
	$url = self_admin_url( 'update-core.php?action=do-plugin-upgrade&plugins=' ) . urlencode( plugin_basename( GRIMLOCK_PLUGIN_FILE ) );
	$url = wp_nonce_url( $url, 'upgrade-core' ); ?>
	<div class="notice notice-error">
		<p><?php printf( esc_html__( '%1$sGrimlock for WooCommerce%2$s requires %1$sGrimlock %3$s%2$s to continue running properly. Please %4$supdate Grimlock.%5$s', 'grimlock-woocommerce' ), '<strong>', '</strong>', GRIMLOCK_WOOCOMMERCE_MIN_GRIMLOCK_VERSION, '<a href="' . esc_url( $url ) . '">', "</a>" ); ?></p>
	</div>
	<?php
}

/**
 * Load plugin.
 */
function grimlock_woocommerce_loaded() {
	if ( version_compare( GRIMLOCK_VERSION, GRIMLOCK_WOOCOMMERCE_MIN_GRIMLOCK_VERSION, '<' ) ) {
		add_action( 'admin_notices', 'grimlock_woocommerce_dependency_notice' );
		return;
	}

	require_once 'inc/class-grimlock-woocommerce.php';

	global $grimlock_woocommerce;
	$grimlock_woocommerce = new Grimlock_WooCommerce();

	do_action( 'grimlock_woocommerce_loaded' );
}
add_action( 'grimlock_loaded', 'grimlock_woocommerce_loaded' );

/**
 * Load YITH WooCommerce Wishlist add on
 */
function grimlock_woocommerce_yith_woocommerce_wishlist_loaded() {
	if ( defined( 'YITH_WCWL' ) ) {
		require_once 'inc/yith-woocommerce-wishlist/grimlock-woocommerce-yith-woocommerce-wishlist-template-functions.php';
		require_once 'inc/yith-woocommerce-wishlist/grimlock-woocommerce-yith-woocommerce-wishlist-template-hooks.php';
	}
}
add_action( 'grimlock_woocommerce_loaded', 'grimlock_woocommerce_yith_woocommerce_wishlist_loaded' );


/**
 * Load YITH WooCommerce Wishlist add on
 */
function grimlock_woocommerce_wc_vendors_loaded() {
	if ( class_exists( 'WC_Vendors' ) ) {
		require_once 'inc/wc-vendors/class-grimlock-woocommerce-wc-vendors.php';
		require_once 'inc/wc-vendors/grimlock-woocommerce-wc-vendors-template-hooks.php';
		global $grimlock_woocommerce_wc_vendors;
		$grimlock_woocommerce_wc_vendors = new Grimlock_WooCommerce_WC_Vendors();
	}
}
add_action( 'grimlock_woocommerce_loaded', 'grimlock_woocommerce_wc_vendors_loaded' );
