<?php
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Grimlock_WooCommerce
 *
 * @author  themoasaurus
 * @since   1.0.0
 * @package grimlock-woocommerce/inc
 */
class Grimlock_WooCommerce {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		load_plugin_textdomain( 'grimlock-woocommerce', false, 'grimlock-woocommerce/languages' );

		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/grimlock-woocommerce-template-functions.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/grimlock-woocommerce-template-hooks.php';

		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/component/class-grimlock-woocommerce-navbar-nav-menu-component.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/component/class-grimlock-woocommerce-product-component.php';

		add_action( 'grimlock_woocommerce_navbar_nav_menu',     array( $this, 'navbar_nav_menu'                        ), 10,  1 );
		add_action( 'grimlock_navbar_nav_menu',                 array( $this, 'add_navbar_nav_menu'                    ), 100, 1 );
		add_action( 'grimlock_vertical_navbar_nav_menu',        array( $this, 'add_navbar_nav_menu'                    ), 100, 1 );
		add_action( 'grimlock_query_product',                   array( $this, 'query_product'                          ), 10,  1 );
		add_action( 'grimlock_modal_product',                   array( $this, 'modal_product'                          ), 10,  1 );
		add_filter( 'grimlock_query_block_query_args',          array( $this, 'change_query_section_query_args'        ), 10,  2 );
		add_filter( 'grimlock_query_section_block_query_args',  array( $this, 'change_query_section_query_args'        ), 10,  2 );
		add_filter( 'grimlock_query_section_widget_query_args', array( $this, 'change_query_section_query_args'        ), 10,  2 );
		add_filter( 'grimlock_query_post_class',                array( $this, 'add_query_wc_product_class'             ), 10,  1 );
		add_filter( 'grimlock_query_section_post_class',        array( $this, 'add_query_wc_product_class'             ), 10,  1 );

		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-typography-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-button-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-navbar-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-table-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-archive-product-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-taxonomy-product-cat-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-taxonomy-product-tag-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-taxonomy-product-attribute-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-taxonomy-wpc-brand-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-single-product-customizer.php';
		require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/customizer/class-grimlock-woocommerce-store-notice-customizer.php';

		add_action( 'customize_controls_enqueue_scripts', array( $this, 'customize_controls_enqueue_scripts' ), 20 );
		add_action( 'wp_enqueue_scripts',                 array( $this, 'enqueue_scripts'                    ), 10 );
		add_action( 'enqueue_block_editor_assets',        array( $this, 'enqueue_block_editor_assets'        ), 10 );

		add_action( 'init',                               array( $this, 'blocks_init'                        ), 10 );
		add_action( 'widgets_init',                       array( $this, 'widgets_init'                       ), 10 );
		add_action( 'after_setup_theme',                  array( $this, 'setup'                              ), 10 );
		add_action( 'after_setup_theme',                  array( $this, 'register_navbar_nav_menus'          ), 10 );

		add_filter( 'wc_get_template',      array( $this, 'wc_get_template'      ), 1, 5 );
		add_filter( 'wc_get_template_part', array( $this, 'wc_get_template_part' ), 1, 3 );

		// Remove some headings on WooCommerce product single post.
		add_filter( 'woocommerce_product_description_heading',            '__return_null' );
		add_filter( 'woocommerce_product_additional_information_heading', '__return_null' );

		remove_filter( 'woocommerce_product_loop_start', 'woocommerce_maybe_show_product_subcategories'  );
		add_filter(    'woocommerce_product_loop_start', array( $this, 'maybe_show_product_categories' ) );

		remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );

		add_filter( 'woocommerce_cross_sells_columns',   array( $this, 'grimlock_woocommerce_change_cross_sells_display' ) );
		add_filter( 'woocommerce_cross_sells_total',     array( $this, 'grimlock_woocommerce_change_cross_sells_display' ) );
		add_filter( 'woocommerce_widget_cart_is_hidden', '__return_false' );
	}

	/**
	 * Display the Grimlock WooCommerce Cart Component for the Navbar.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	public function navbar_nav_menu( $args = array() ) {
		$args = apply_filters( 'grimlock_woocommerce_navbar_nav_menu_args', wp_parse_args( $args, array(
			'id' => 'woocommerce-navbar_nav_menu',
		) ) );
		$component = new Grimlock_WooCommerce_Navbar_Nav_Menu_Component( $args );
		$component->render();
	}

	/**
	 * Add WooCommerce navbar cart for the Grimlock Navbar.
	 *
	 * @param $args
	 * @since 1.0.0
	 */
	public function add_navbar_nav_menu( $args ) {
		$class = isset( $args['menu_class'] ) ? str_replace( 'main-menu', 'woocommerce', $args['menu_class'] ) : '';
		do_action( 'grimlock_woocommerce_navbar_nav_menu', array(
			'class' => $class,
		) );
	}

	/**
	 * Display the product component.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args
	 */
	public function query_product( $args = array() ) {
		$component = new Grimlock_WooCommerce_Product_Component( apply_filters( 'grimlock_query_product_args', $args ) );
		$component->render();
	}

	/**
	 * Display the product modal component.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args
	 */
	public function modal_product( $args = array() ) {
		echo WC_Shortcodes::product_page( apply_filters( 'grimlock_modal_product_args', $args ) );
	}

	/**
	 * Change the arguments for the query displayed in the Query Widget.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $query_args  The array of arguments for the query.
	 * @param  array $widget_args The array of arguments for the widget.
	 *
	 * @return array              The updated array of arguments for the query.
	 */
	public function change_query_section_query_args( $query_args, $widget_args ) {
		if ( 'product' === $widget_args['post_type'] ) {

			$hide_out_of_stock = get_option( 'woocommerce_hide_out_of_stock_items' );

			if ( 'yes' === $hide_out_of_stock ) {
				$query_args['tax_query'][] = array(
					'taxonomy' => 'product_visibility',
					'field'    => 'name',
					'terms'    => 'outofstock',
					'operator' => 'NOT IN',
				);
			}
		}
		return $query_args;
	}

	/**
	 * Add wc product classes to the post class in query component
	 *
	 * @param array $classes
	 *
	 * @return array
	 */
	public function add_query_wc_product_class( $classes ) {
		if ( get_post_type( get_the_ID() ) === 'product' ) {
			return wc_get_product_class( $classes );
		}

		return $classes;
	}

	/**
	 * Enqueue script for customizer controls.
	 *
	 * @since 1.0.2
	 */
	public function customize_controls_enqueue_scripts() {
		wp_enqueue_script( 'grimlock-woocommerce-customizer-controls', GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_URL . 'assets/js/customizer-controls.js', array( 'grimlock-customizer-controls' ), GRIMLOCK_WOOCOMMERCE_VERSION, true );
	}

	/**
	 * Enqueue scripts
	 */
	public function enqueue_scripts() {
		wp_enqueue_style( 'grimlock-woocommerce', GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_URL . 'assets/css/style.css', array(), GRIMLOCK_WOOCOMMERCE_VERSION );

		/*
		 * Load style-rtl.css instead of style.css for RTL compatibility
		 */
		wp_style_add_data( 'grimlock-woocommerce', 'rtl', 'replace' );

		wp_enqueue_script( 'grimlock-woocommerce', GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_URL . 'assets/js/main.js', array( 'jquery' ), GRIMLOCK_WOOCOMMERCE_VERSION, true );
	}

	/**
	 * Enqueue scripts and stylesheets in the block editor
	 *
	 * @since 1.0.0
	 */
	public function enqueue_block_editor_assets() {
		wp_register_style( 'grimlock-woocommerce-blocks', GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_URL . "assets/css/block-editor.css", array( 'wp-edit-blocks' ), GRIMLOCK_WOOCOMMERCE_VERSION );
		wp_enqueue_style( 'grimlock-woocommerce-blocks' );
	}

	/**
	 * Register blocks
	 */
	public function blocks_init() {
		if ( get_theme_support( 'grimlock-wrapper-block' ) ) {
			require_once GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'inc/block/products/class-grimlock-woocommerce-products-block.php';
		}
	}

	/**
	 * Register widget areas.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
	 * @since 1.2.0
	 */
	public function widgets_init() {
		register_sidebar( array(
			'id'            => 'wc-filters-sidebar',
			'name'          => esc_html__( 'WooCommerce Filters', 'grimlock-woocommerce' ),
			'description'   => esc_html__( 'The area for the filters displayed in WooCommerce pages.', 'grimlock-woocommerce' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );

		register_sidebar( apply_filters( 'grimlock_woocommerce_sidebar_1_args', array(
			'id'            => 'wc-sidebar-1',
			'name'          => esc_html__( 'WooCommerce Left Sidebar', 'grimlock-woocommerce' ),
			'description'   => esc_html__( 'The left hand area for the WooCommerce shop.', 'grimlock-woocommerce' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) ) );

		register_sidebar( apply_filters( 'grimlock_woocommerce_sidebar_2_args', array(
			'id'            => 'wc-sidebar-2',
			'name'          => esc_html__( 'WooCommerce Right Sidebar', 'grimlock-woocommerce' ),
			'description'   => esc_html__( 'The right hand area for the WooCommerce shop.', 'grimlock-woocommerce' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) ) );
	}

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 *
	 * @since 1.2.0
	 */
	public function setup() {
		add_theme_support( 'woocommerce', array(
			'gallery_thumbnail_image_width' => 150,
		) );
		add_theme_support( 'wc-product-gallery-zoom'     );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider'   );
	}


	/**
	 * Register nav menus for the Grimlock Navbar component.
	 */
	public function register_navbar_nav_menus() {
		if ( apply_filters( 'grimlock_woocommerce_navbar_nav_menu_wc_account_displayed', false ) ) {
			register_nav_menus( apply_filters( 'grimlock_woocommerce_nav_menus', array(
				'wc_account_logged_in'  => esc_html__( 'My Account Logged In', 'grimlock-woocommerce' ),
				'wc_account_logged_out' => esc_html__( 'My Account Logged Out', 'grimlock-woocommerce' ),
			) ) );
		}
	}

	/**
	 * Modify the template hierarchy to locate them in the "templates" folder of this plugin if not overridden in the theme
	 *
	 * @param string $template The full path of the template to modify
	 * @param string $template_name The template name
	 * @param array  $args Array of args used to locate the template
	 * @param string $template_path The path where template overrides are located in the theme
	 * @param string $default_path The path where default templates are located (usually in WooCommerce)
	 *
	 * @return string The full template path
	 */
	public function wc_get_template( $template, $template_name, $args, $template_path, $default_path ) {
		if ( ! $template_path ) {
			$template_path = WC()->template_path();
		}

		if ( ! $default_path ) {
			$default_path = WC()->plugin_path() . '/templates/';
		}

		// Avoid overriding templates that are already overwritten
		if ( strpos( $template, $default_path ) === false ) {
			return $template;
		}

		// Look within passed path within the theme - this is priority.
		$theme_template = locate_template(
			array(
				trailingslashit( $template_path ) . $template_name,
				$template_name,
			)
		);

		$plugin_template = GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . 'templates/' . $template_name;
		$default_template = $default_path . $template_name;

		if ( $theme_template ) {
			return $theme_template;
		}
		elseif ( file_exists( $plugin_template ) ) {
			return $plugin_template;
		}
		elseif ( file_exists( $default_template ) ) {
			return $default_template;
		}

		return $template;
	}

	/**
	 * Try to locate WooCommerce templates parts in the plugin
	 *
	 * @param string $template The template to modify
	 * @param string $slug The template slug
	 * @param string $name The template name
	 *
	 * @return string The template
	 */
	public function wc_get_template_part( $template, $slug, $name ) {
		if ( $name ) {
			$theme_template = locate_template(
				array(
					"{$slug}-{$name}.php",
					WC()->template_path() . "{$slug}-{$name}.php",
				)
			);

			$plugin_template = GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_PATH . "templates/{$slug}-{$name}.php";
			$default_template = WC()->plugin_path() . "/templates/{$slug}-{$name}.php";

			if ( $theme_template ) {
				return $theme_template;
			}
			elseif ( file_exists( $plugin_template ) ) {
				return $plugin_template;
			}
			elseif ( file_exists( $default_template ) ) {
				return $default_template;
			}
		}

		return $template;
	}

	/**
	 * Display the product categories if needed
	 *
	 * @param string $loop_html The html for the products loop.
	 *
	 * @return string The modified html for the products loop.
	 */
	public function maybe_show_product_categories( $loop_html ) {
		if ( ! $GLOBALS['woocommerce_loop']['is_shortcode'] ) {

			$display_type = woocommerce_get_loop_display_mode();

			// If displaying categories, append to the loop.
			if ( 'subcategories' === $display_type || 'both' === $display_type ) {
				$parent_id  = is_product_category() ? get_queried_object_id() : 0;
				$categories = woocommerce_get_product_subcategories( $parent_id );

				if ( ! empty( $categories ) ) {
					$loop_html .= sprintf( '<li class="product-categories product-categories-count--%s w-100 d-block float-left clearfix"><ul>', count( $categories ) );
					$loop_html  = woocommerce_maybe_show_product_subcategories( $loop_html );
					$loop_html .= '</ul></li>';
				}
			}
		}

		return $loop_html;
	}

	public function grimlock_woocommerce_change_cross_sells_display( $columns ) {
		return 3;
	}
}
