<?php
/**
 * Grimlock_WooCommerce_Navbar_Nav_Menu_Component Class
 *
 * @author  Themosaurus
 * @since   1.0.0
 * @package  grimlock
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Grimlock_WooCommerce_Navbar_Nav_Menu_Component
 */
class Grimlock_WooCommerce_Navbar_Nav_Menu_Component extends Grimlock_Component {
	/**
	 * Render the current component with props data on page.
	 *
	 * @since 1.0.0
	 */
	public function render() {
		?>
		<ul <?php $this->render_class(); ?>>

			<?php if ( apply_filters( 'grimlock_woocommerce_navbar_nav_menu_wc_account_displayed', false ) ) : ?>

				<li class="menu-item <?php echo has_nav_menu( 'wc_account_logged_in' ) || has_nav_menu( 'wc_account_logged_out' ) ? 'menu-item-has-children' : ''; ?> menu-item--wc-account">
					<?php if ( is_user_logged_in() ) : ?>
						<a href="<?php echo esc_url( wc_get_account_endpoint_url( 'dashboard' ) ); ?>" class="menu-item--wc-account__link <?php echo ! has_nav_menu( 'wc_account_logged_in' ) ? 'no-toggle' : ''; ?>">
							<span class="menu-item--wc-account__label"><?php esc_html_e( 'My Account', 'grimlock-woocommerce' ); ?></span>
						</a>

						<?php
						if ( has_nav_menu( 'wc_account_logged_in' ) ) :
							wp_nav_menu( array(
								'theme_location' => 'wc_account_logged_in',
								'container'      => false,
								'menu_class'     => 'sub-menu',
							) );
						endif;
					else : ?>

						<a href="<?php echo esc_url( wc_get_account_endpoint_url( 'dashboard' ) ); ?>" class="menu-item--wc-account__link <?php echo ! has_nav_menu( 'wc_account_logged_in' ) ? 'no-toggle' : ''; ?>">
							<span class="menu-item--wc-account__label"><?php esc_html_e( 'My Account', 'grimlock-woocommerce' ); ?></span>
						</a>

						<?php
						if ( has_nav_menu( 'wc_account_logged_out' ) ) :
							wp_nav_menu( array(
								'theme_location' => 'wc_account_logged_out',
								'container'      => false,
								'menu_class'     => 'sub-menu',
							) );
						endif;
					endif; ?>
				</li>

			<?php endif; ?>

			<?php if ( class_exists( 'WPCleverWpcas' ) && apply_filters( 'grimlock_woocommerce_navbar_nav_menu_product_search_displayed', true ) ) : ?>

				<li class="menu-item wpcas-menu-item menu-item-type-wpcas">
					<a href="#">
						<?php esc_html_e( 'Search', 'wpc-ajax-search' ); ?>
					</a>
				</li>

			<?php endif; ?>

			<?php if ( class_exists( 'WPCleverWoosc' ) && apply_filters( 'grimlock_woocommerce_navbar_nav_menu_product_compare_displayed', true ) ) :
				// Hack to call non-static method that could be static in WPCleverWoosc class
				$woosc_reflection = new ReflectionClass( 'WPCleverWoosc' );
				$woosc_obj        = $woosc_reflection->newInstanceWithoutConstructor(); ?>

				<li class="<?php echo esc_attr( apply_filters( 'woosc_menu_item_class', 'menu-item woosc-menu-item menu-item-type-woosc' ) ); ?>">

					<a href="<?php echo esc_url( WPCleverWoosc::get_url() ); ?>">
						<span class="woosc-menu-item-inner" data-count="<?php echo esc_attr( WPCleverWoosc::get_count() ); ?>">
							<?php echo apply_filters( 'woosc_menu_item_label', $woosc_obj->localization( 'menu', esc_html__( 'Compare', 'woo-smart-compare' ) ) ); ?>
						</span>
					</a>

				</li>

			<?php endif; ?>

			<?php if ( class_exists( 'WPCleverWoosw' ) && apply_filters( 'grimlock_woocommerce_navbar_nav_menu_product_wishlist_displayed', true ) ) :
				// Hack to call non-static method that could be static in WPCleverWoosw class
				$woosw_reflection = new ReflectionClass( 'WPCleverWoosw' );
				$woosw_obj        = $woosw_reflection->newInstanceWithoutConstructor(); ?>

				<li class="<?php echo esc_attr( apply_filters( 'woosw_menu_item_class', 'menu-item woosw-menu-item menu-item-type-woosw' ) ); ?>">

					<a href="<?php echo esc_url( WPCleverWoosw::get_url() ); ?>">
						<span class="woosw-menu-item-inner" data-count="<?php echo esc_attr( WPCleverWoosw::get_count() ); ?>">
							<?php echo apply_filters( 'woosw_menu_item_label', $woosw_obj->localization( 'menu_label', esc_html__( 'Wishlist', 'woo-smart-wishlist' ) ) ); ?>
						</span>
					</a>

				</li>

			<?php endif; ?>

			<?php if ( apply_filters( 'grimlock_woocommerce_navbar_nav_menu_mini_cart_displayed', true ) ) : ?>

				<li class="menu-item menu-item-has-children">

					<?php if ( apply_filters( 'grimlock_woocommerce_navbar_nav_menu_mini_cart_type', 'dropdown' ) === 'dropdown' ) : ?>

						<?php grimlock_woocommerce_cart_link(); ?>
						<ul class="sub-menu">
							<li>
								<?php do_action( 'grimlock_woocommerce_navbar_nav_menu_cart_sub_menu', $this->props ); ?>
							</li>
						</ul>

					<?php else :

						$mini_cart_block = parse_blocks( '<!-- wp:woocommerce/mini-cart {"addToCartBehaviour":"open_drawer"} /-->' );
						echo render_block( $mini_cart_block[0] );

					endif; ?>

				</li>

			<?php endif; ?>

		</ul>
		<?php
	}
}
