<?php
/**
 * Grimlock_WooCommerce_Archive_Product_Customizer Class
 *
 * @author  Themosaurus
 * @since   1.0.0
 * @package grimlock
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock Customizer class for the product archive pages.
 */
class Grimlock_WooCommerce_Archive_Product_Customizer extends Grimlock_Template_Customizer {

	/**
	 * @since 1.0.2
	 *
	 * @var WP_Post The shop page post
	 */
	protected $shop_page;

	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->id        = 'archive_product';
		$this->section   = 'woocommerce_product_catalog';
		$this->shop_page = get_post( get_option( 'woocommerce_shop_page_id' ) );

		add_action( 'after_setup_theme',                                             array( $this, 'add_customizer_fields'                                           ), 20    );

		add_filter( 'body_class',                                                    array( $this, 'add_body_classes'                                                ), 10, 1 );

		add_filter( 'grimlock_customizer_controls_js_data',                          array( $this, 'add_customizer_controls_js_data'                                 ), 10, 1 );
		add_filter( 'grimlock_content_class',                                        array( $this, 'add_content_classes'                                             ), 20, 1 );
		add_filter( 'grimlock_custom_header_args',                                   array( $this, 'add_custom_header_args'                                          ), 20, 1 );
		add_filter( 'grimlock_custom_header_displayed',                              array( $this, 'has_custom_header_displayed'                                     ), 10, 1 );
		add_filter( 'grimlock_template_sidebar_right_displayed',                     array( $this, 'has_sidebar_right_displayed'                                     ), 10, 1 );
		add_filter( 'grimlock_template_sidebar_left_displayed',                      array( $this, 'has_sidebar_left_displayed'                                      ), 10, 1 );
		add_filter( 'grimlock_archive_customizer_is_template',                       array( $this, 'archive_customizer_is_template'                                  ), 10, 1 );
		add_filter( 'grimlock_query_product_args',                                   array( $this, 'add_product_args'                                                ), 10, 1 );
		add_filter( 'grimlock_woocommerce_product_args',                             array( $this, 'add_product_args'                                                ), 10, 1 );
		add_filter( 'wp',                                                            array( $this, 'remove_shop_loop_actions'                                        ), 999, 0 );
		add_filter( 'grimlock_template_sidebar_left_id',                             array( $this, 'change_sidebar_left_id'                                          ), 10, 1 );
		add_filter( 'grimlock_template_sidebar_right_id',                            array( $this, 'change_sidebar_right_id'                                         ), 10, 1 );

		add_filter( 'grimlock_custom_header_customizer_padding_y_field_args',        array( $this, 'add_custom_header_customizer_padding_y_field_description'        ), 10, 1 );
		add_filter( 'grimlock_custom_header_customizer_layout_field_args',           array( $this, 'add_custom_header_customizer_layout_field_description'           ), 10, 1 );
		add_filter( 'grimlock_custom_header_customizer_container_layout_field_args', array( $this, 'add_custom_header_customizer_container_layout_field_description' ), 10, 1 );

		add_filter( 'grimlock_woocommerce_content_product_cat_layout',               array( $this, 'content_product_cat_layout'                                      ), 10, 1 );
		add_filter( 'grimlock_woocommerce_product_button_format',                    array( $this, 'product_button_format'                                           ), 10, 1 );

		add_filter( 'kirki_grimlock_dynamic_css',                                    array( $this, 'add_dynamic_css'                                                 ), 10, 1 );
	}

	/**
	 * Add custom classes to body to modify layout.
	 *
	 * @param $classes
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function add_body_classes( $classes ) {
		$classes = parent::add_body_classes( $classes );

		$layout    = $this->get_theme_mod( 'product_cat_layout' );
		$classes[] = "grimlock-woocommerce-products-categories--{$layout}";

		$button_format = $this->get_theme_mod( 'archive_product_button_format' );
		$classes[]     = "grimlock-woocommerce--archive-product-button-format-{$button_format}";

		if ( empty( $this->get_theme_mod( 'archive_product_cards_enabled' ) ) ) {
			$classes[] = 'grimlock-woocommerce--archive-product-cards-disabled';
		}

		return $classes;
	}

	/**
	 * Add custom classes to content to modify layout.
	 *
	 * @param string[] $classes
	 *
	 * @return string[]
	 */
	public function add_content_classes( $classes ) {
		if ( $this->is_template() ) {
			foreach ( $classes as $key => $class ) {
				if ( strpos( $class, 'region--' ) !== false ) {
					unset( $classes[ $key ] );
				}
			}
			$classes = parent::add_content_classes( $classes );
		}
		return $classes;
	}

	/**
	 * Add tabs to the Customizer to group controls.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $js_data The array of data for the Customizer controls.
	 *
	 * @return array          The filtred array of data for the Customizer controls.
	 */
	public function add_customizer_controls_js_data( $js_data ) {
		$js_data['tabs'][ $this->section ] = array(
			array(
				'label' => esc_html__( 'General', 'grimlock-woocommerce' ),
				'class' => 'archive_product-general-tab',
				'controls' => array(
					'woocommerce_shop_page_display',
					'woocommerce_category_archive_display',
					'woocommerce_default_catalog_orderby',
					'woocommerce_catalog_columns',
					'woocommerce_catalog_rows',
					'archive_product_title',
					"{$this->section}_divider_20",
					'archive_product_description',
					"{$this->section}_divider_30",
					"{$this->section}_heading_30",
					'archive_product_custom_header_displayed',
					"{$this->section}_divider_40",
					"{$this->section}_heading_40",
					'archive_product_thumbnail_displayed',
					'archive_product_excerpt_displayed',
					'archive_product_category_displayed',
					'archive_product_add_to_cart_displayed',
					'archive_product_rating_displayed',
					'archive_product_price_displayed',
					'archive_product_on_sale_displayed',
					'archive_product_out_of_stock_displayed',
				),
			),
			array(
				'label' => esc_html__( 'Layout', 'grimlock-woocommerce' ),
				'class' => 'archive_product-layout-tab',
				'controls' => array(
					'archive_product_custom_header_layout',
					'archive_product_custom_header_boxed',
					"{$this->section}_divider_210",
					'archive_product_custom_header_container_layout',
					"{$this->section}_divider_220",
					'product_cat_layout',
					'archive_product_cards_enabled',
					"{$this->section}_divider_240",
					'archive_product_layout',
					'archive_product_sidebar_mobile_displayed',
					"{$this->section}_divider_260",
					'archive_product_container_layout',
				),
			),
			array(
				'label' => esc_html__( 'Style', 'grimlock-woocommerce' ),
				'class' => 'archive_product-style-tab',
				'controls' => array(
					'archive_product_custom_header_background_image',
					"{$this->section}_divider_310",
					'archive_product_custom_header_padding_y',
					"{$this->section}_divider_320",
					'archive_product_content_padding_y',
					"{$this->section}_divider_330",
					"archive_product_button_format",
				),
			),
		);
		return $js_data;
	}

	/**
	 * Register default values, settings and custom controls for the Theme Customizer.
	 *
	 * @since 1.0.0
	 */
	public function add_customizer_fields() {
		$this->defaults = apply_filters( 'grimlock_woocommerce_archive_product_customizer_defaults', array(
			'archive_product_title'                          => '',
			'archive_product_description'                    => '',
			'archive_product_custom_header_displayed'        => has_header_image(),

			'archive_product_thumbnail_displayed'            => true,
			'archive_product_excerpt_displayed'              => false,
			'archive_product_category_displayed'             => false,
			'archive_product_add_to_cart_displayed'          => true,
			'archive_product_rating_displayed'               => true,
			'archive_product_price_displayed'                => true,
			'archive_product_on_sale_displayed'              => true,
			'archive_product_out_of_stock_displayed'         => false,

			'archive_product_custom_header_layout'           => '6-6-cols-left-reverse',
			'archive_product_custom_header_boxed'            => false,
			'archive_product_custom_header_container_layout' => 'classic',
			'product_cat_layout'                             => 'layout_grid',
			'archive_product_layout'                         => '12-cols-left',
			'archive_product_cards_enabled'                  => true,
			'archive_product_sidebar_mobile_displayed'       => true,
			'archive_product_container_layout'               => 'classic',

			'archive_product_custom_header_background_image' => get_header_image(),
			'archive_product_custom_header_padding_y'        => GRIMLOCK_SECTION_PADDING_Y,
			'archive_product_content_padding_y'              => GRIMLOCK_CONTENT_PADDING_Y,
			'archive_product_button_format'                  => 'icon',
		) );

		$this->add_title_field(                          array( 'priority' => 10  ) );
		$this->add_divider_field(                        array( 'priority' => 20  ) );
		$this->add_description_field(                    array( 'priority' => 20  ) );
		$this->add_divider_field(                        array( 'priority' => 30  ) );
		$this->add_heading_field(                        array( 'priority' => 30, 'label' => esc_html__( 'Header Display', 'grimlock-woocommerce' ) ) );
		$this->add_custom_header_displayed_field(        array( 'priority' => 30  ) );
		$this->add_divider_field(                        array( 'priority' => 40  ) );
		$this->add_heading_field(                        array( 'priority' => 40, 'label' => esc_html__( 'Product Display', 'grimlock-woocommerce' ) ) );
		$this->add_thumbnail_displayed_field(            array( 'priority' => 40  ) );
		$this->add_excerpt_displayed_field(              array( 'priority' => 50  ) );
		$this->add_category_displayed_field(             array( 'priority' => 60  ) );
		$this->add_add_to_cart_displayed_field(          array( 'priority' => 70  ) );
		$this->add_rating_displayed_field(               array( 'priority' => 80  ) );
		$this->add_price_displayed_field(                array( 'priority' => 90  ) );
		$this->add_on_sale_displayed_field(              array( 'priority' => 100 ) );
		$this->add_out_of_stock_displayed_field(         array( 'priority' => 110 ) );

		$this->add_custom_header_layout_field(           array( 'priority' => 200 ) );
		$this->add_custom_header_boxed_field(            array( 'priority' => 205 ) );
		$this->add_divider_field(                        array( 'priority' => 210 ) );
		$this->add_custom_header_container_layout_field( array( 'priority' => 210 ) );
		$this->add_divider_field(                        array( 'priority' => 220 ) );
		$this->add_product_cat_layout_field(             array( 'priority' => 220 ) );
		$this->add_cards_enabled_field(                  array( 'priority' => 230 ) );
		$this->add_divider_field(                        array( 'priority' => 240 ) );
		$this->add_layout_field(                         array( 'priority' => 240 ) );
		$this->add_sidebar_mobile_displayed_field(       array( 'priority' => 250 ) );
		$this->add_divider_field(                        array( 'priority' => 260 ) );
		$this->add_container_layout_field(               array( 'priority' => 260 ) );

		$this->add_custom_header_background_image_field( array( 'priority' => 300 ) );
		$this->add_divider_field(                        array( 'priority' => 310 ) );
		$this->add_custom_header_padding_y_field(        array( 'priority' => 310 ) );
		$this->add_divider_field(                        array( 'priority' => 320 ) );
		$this->add_content_padding_y_field(              array( 'priority' => 320 ) );
		$this->add_divider_field(                        array( 'priority' => 330 ) );
		$this->add_button_format_field(                  array( 'priority' => 330 ) );
	}

	/**
	 * Check if shop page has been set.
	 *
	 * @since 1.0.2
	 *
	 * @return bool True when shop page has been set, false otherwise.
	 */
	protected function has_shop_page() {
		return ! empty( $this->shop_page ) && $this->shop_page instanceof WP_Post;
	}

	/**
	 * Get the default title.
	 *
	 * @since 1.0.2
	 *
	 * @return string The shop page title.
	 */
	protected function get_title_default() {
		return $this->has_shop_page() ? get_the_title( $this->shop_page->ID ) : $this->get_default( 'archive_product_title' );
	}

	/**
	 * Get the default description.
	 *
	 * @since 1.0.2
	 *
	 * @return string The default description.
	 */
	protected function get_description_default() {
		return $this->has_shop_page() ? $this->shop_page->post_excerpt : $this->get_default( 'archive_product_description' );
	}

	/**
	 * Get the default URL for the custom header background image.
	 *
	 * @since 1.0.2
	 *
	 * @return string The default URL for the custom header backgroud image.
	 */
	protected function get_custom_header_background_image_default() {
		$shop_page_thumbnail_url = '';

		if ( $this->has_shop_page() ) {
			$shop_page_thumbnail_id   = get_post_thumbnail_id( $this->shop_page->ID );
			$shop_page_thumbnail_atts = ! empty( $shop_page_thumbnail_id ) ? wp_get_attachment_image_src( $shop_page_thumbnail_id, 'custom-header' ) : false;
			$shop_page_thumbnail_url  = ! empty( $shop_page_thumbnail_atts[0] ) ? $shop_page_thumbnail_atts[0] : '';
		}
		return ! empty( $shop_page_thumbnail_url ) ? $shop_page_thumbnail_url : $this->get_default( 'archive_product_custom_header_background_image' );
	}

	/**
	 * Add a Kirki text field to set the title in the Customizer.
	 *
	 * @since 1.0.2
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_title_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'              => 'text_disabled',
				'label'             => esc_html__( 'Title', 'grimlock-woocommerce' ),
				'description'       => esc_html__( 'You can change the header title of the shop page by editing its title in the admin.', 'grimlock-woocommerce' ),
				'section'           => $this->section,
				'settings'          => 'archive_product_title',
				'default'           => $this->get_title_default(),
				'priority'          => 10,
				'sanitize_callback' => 'wp_kses_post',
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_archive_product_customizer_title_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki textarea field to set the description in the Customizer.
	 *
	 * @since 1.0.2
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_description_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'              => 'textarea_disabled',
				'label'             => esc_html__( 'Description', 'grimlock-woocommerce' ),
				'description'       => esc_html__( 'You can change the header text of the shop page by editing its excerpt in the admin.', 'grimlock-woocommerce' ),
				'section'           => $this->section,
				'settings'          => 'archive_product_description',
				'default'           => $this->get_description_default(),
				'priority'          => 10,
				'sanitize_callback' => 'wp_kses_post',
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_archive_product_customizer_description_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set the thumbnail display in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_thumbnail_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display thumbnails', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_thumbnail_displayed",
				'default'  => $this->get_default( "{$this->id}_thumbnail_displayed" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_woocommerce_{$this->id}_customizer_thumbnail_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set the excerpt display in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_excerpt_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display excerpts', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_excerpt_displayed",
				'default'  => $this->get_default( "{$this->id}_excerpt_displayed" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_woocommerce_{$this->id}_customizer_excerpt_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set the category display in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_category_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display categories', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_category_displayed",
				'default'  => $this->get_default( "{$this->id}_category_displayed" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_woocommerce_{$this->id}_customizer_category_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set the add to cart buttons display in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_add_to_cart_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display add to cart buttons', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_add_to_cart_displayed",
				'default'  => $this->get_default( "{$this->id}_add_to_cart_displayed" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_woocommerce_{$this->id}_customizer_add_to_cart_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set the rating display in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_rating_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display ratings', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_rating_displayed",
				'default'  => $this->get_default( "{$this->id}_rating_displayed" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_woocommerce_{$this->id}_customizer_rating_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set the price display in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_price_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display prices', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_price_displayed",
				'default'  => $this->get_default( "{$this->id}_price_displayed" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_woocommerce_{$this->id}_customizer_price_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set the on sale badge display in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_on_sale_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display on sale badges', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_on_sale_displayed",
				'default'  => $this->get_default( "{$this->id}_on_sale_displayed" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_woocommerce_{$this->id}_customizer_on_sale_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set the out of stock badge display in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_out_of_stock_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display out of stock badges', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_out_of_stock_displayed",
				'default'  => $this->get_default( "{$this->id}_out_of_stock_displayed" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_woocommerce_{$this->id}_customizer_out_of_stock_displayed_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki image field to set the background image for the Custom Header in the Customizer.
	 *
	 * @since 1.0.2
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_custom_header_background_image_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'        => 'image',
				'section'     => $this->section,
				'label'       => esc_html__( 'Header Image', 'grimlock-woocommerce' ),
				'description' => esc_html__( 'You can change the header image of the shop page by editing its featured image in the admin.', 'grimlock-woocommerce' ),
				'settings'    => 'archive_product_custom_header_background_image',
				'default'     => $this->get_custom_header_background_image_default(),
				'priority'    => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_archive_product_customizer_custom_header_background_image_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki radio-image field to set the template content layout in the Customizer.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args The array of arguments for the Kirki radio image field.
	 */
	protected function add_product_cat_layout_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'radio-image',
				'section'  => $this->section,
				'label'    => esc_html__( 'Product Categories Layout', 'grimlock-woocommerce' ),
				'settings' => 'product_cat_layout',
				'default'  => $this->get_default( 'product_cat_layout' ),
				'priority' => 10,
				'choices'  => array(
					'layout_default' => GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_URL . '/assets/images/template-products-categories-default.png',
					'layout_grid'    => GRIMLOCK_WOOCOMMERCE_PLUGIN_DIR_URL . '/assets/images/template-products-categories-grid.png',
				),
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_archive_product_customizer_product_cat_layout_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox to set whether to use the cards design for the products in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_cards_enabled_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display products as cards', 'grimlock-woocommerce' ),
				'settings' => "{$this->id}_cards_enabled",
				'default'  => $this->get_default( "{$this->id}_cards_enabled" ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( "grimlock_{$this->id}_customizer_cards_enabled_field_args", $args ) );
		}
	}

	/**
	 * Add a Kirki select control to set the button format in the Customizer
	 *
	 * @since 1.0.6
	 *
	 * @param array $args
	 */
	protected function add_button_format_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'select',
				'section'  => $this->section,
				'label'    => esc_html__( 'Buttons Format', 'grimlock-woocommerce' ),
				'settings' => 'archive_product_button_format',
				'default'  => $this->get_default( 'archive_product_button_format' ),
				'priority' => 10,
				'choices'  => array(
					'icon' => esc_html__( 'Icon', 'grimlock-woocommerce' ),
					'text' => esc_html__( 'Text', 'grimlock-woocommerce' ),
					'icon-main-button' => esc_html__( 'Icon + Main button', 'grimlock-woocommerce' ),
				),
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_archive_product_button_format', $args ) );
		}
	}

	/**
	 * Add the post type to display the title in Custom Header.
	 *
	 * @since 1.0.0
	 *
	 * @param $args
	 *
	 * @return array
	 */
	public function add_custom_header_args( $args ) {
		$args = parent::add_custom_header_args( $args );

		if ( $this->is_template() ) {
			// Use default values for background image, title and subtitle as they read only with the Customizer.
			$args['background_image'] = $this->get_custom_header_background_image_default();
			$args['title']            = $this->get_title_default();
			$args['subtitle']         = "<span class='excerpt'>{$this->get_description_default()}</span>";
		}
		return $args;
	}

	/**
	 * Check if the current template is the expected template, the shop page or a similar template.
	 *
	 * @since 1.0.0
	 *
	 * @return bool True when the template is the expected template, false otherwise.
	 */
	protected function is_template() {
		$is_template = function_exists( 'is_shop' ) && is_shop();
		return apply_filters( 'grimlock_woocommerce_archive_product_customizer_is_template', $is_template );
	}

	/**
	 * Disinherit archive customizer settings
	 *
	 * @param bool $default True if we are on a default archive page
	 *
	 * @return bool
	 */
	public function archive_customizer_is_template( $default ) {
		return $default && ! $this->is_template();
	}

	/**
	 * Add arguments using theme mods to customize the product.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args The default arguments to render the post.
	 *
	 * @return array      The arguments to render the post.
	 */
	public function add_product_args( $args = array() ) {
		$args['post_thumbnail_displayed']       = $this->get_theme_mod( 'archive_product_thumbnail_displayed' );
		$args['post_excerpt_displayed']         = $this->get_theme_mod( 'archive_product_excerpt_displayed' );
		$args['product_category_displayed']     = $this->get_theme_mod( 'archive_product_category_displayed' );
		$args['product_add_to_cart_displayed']  = $this->get_theme_mod( 'archive_product_add_to_cart_displayed' );
		$args['product_rating_displayed']       = $this->get_theme_mod( 'archive_product_rating_displayed' );
		$args['product_price_displayed']        = $this->get_theme_mod( 'archive_product_price_displayed' );
		$args['product_on_sale_displayed']      = $this->get_theme_mod( 'archive_product_on_sale_displayed' );
		$args['product_out_of_stock_displayed'] = $this->get_theme_mod( 'archive_product_out_of_stock_displayed' );

		return $args;
	}

	/**
	 * Remove actions in product items depending on theme mods
	 */
	public function remove_shop_loop_actions() {
		if ( empty( $this->get_theme_mod( 'archive_product_on_sale_displayed' ) ) ) {
			remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
		}

		if ( empty( $this->get_theme_mod( 'archive_product_thumbnail_displayed' ) ) ) {
			remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
		}

		if ( empty( $this->get_theme_mod( 'archive_product_rating_displayed' ) ) ) {
			remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 11 );
		}

		if ( empty( $this->get_theme_mod( 'archive_product_price_displayed' ) ) ) {
			remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
		}
	}

	/**
	 * Change the sidebar left id to display a WooCommerce specific sidebar
	 *
	 * @param string $sidebar_id The id of the sidebar to modify
	 *
	 * @return string The modified id of the sidebar
	 */
	public function change_sidebar_left_id( $sidebar_id ) {
		if ( $this->is_template() ) {
			return 'wc-sidebar-1';
		}
		return $sidebar_id;
	}

	/**
	 * Change the sidebar right id to display a WooCommerce specific sidebar
	 *
	 * @param string $sidebar_id The id of the sidebar to modify
	 *
	 * @return string The modified id of the sidebar
	 */
	public function change_sidebar_right_id( $sidebar_id ) {
		if ( $this->is_template() ) {
			return 'wc-sidebar-2';
		}
		return $sidebar_id;
	}

	/**
	 * Add a link in the description pointing to the product archive vertical padding field.
	 *
	 * @since 1.0.2
	 *
	 * @param  array $args The array of arguments for the Kirki field.
	 *
	 * @return array       The updated array of arguments for the Kirki field.
	 */
	public function add_custom_header_customizer_padding_y_field_description( $args ) {
		$args['description'] .= wp_kses( __( ', <a href="#archive_product_custom_header_padding_y" rel="tc-control">Shop Page</a>', 'grimlock-woocommerce' ), array(
			'a' => array(
				'href' => array(),
				'rel'  => array(),
			),
		) );
		return $args;
	}

	/**
	 * Add a link in the description pointing to the product archive layout field.
	 *
	 * @since 1.0.2
	 *
	 * @param  array $args The array of arguments for the Kirki field.
	 *
	 * @return array       The updated array of arguments for the Kirki field.
	 */
	public function add_custom_header_customizer_layout_field_description( $args ) {
		$args['description'] .= wp_kses( __( ', <a href="#archive_product_custom_header_layout" rel="tc-control">Shop Page</a>', 'grimlock-woocommerce' ), array(
			'a' => array(
				'href' => array(),
				'rel'  => array(),
			),
		) );
		return $args;
	}

	/**
	 * Add a link in the description pointing to the product archive container layout field.
	 *
	 * @since 1.0.2
	 *
	 * @param  array $args The array of arguments for the Kirki field.
	 *
	 * @return array       The updated array of arguments for the Kirki field.
	 */
	public function add_custom_header_customizer_container_layout_field_description( $args ) {
		$args['description'] .= wp_kses( __( ', <a href="#archive_product_custom_header_container_layout" rel="tc-control">Shop Page</a>', 'grimlock-woocommerce' ), array(
			'a' => array(
				'href' => array(),
				'rel'  => array(),
			),
		) );
		return $args;
	}

	/**
	 * Return the category layout for the product categories.
	 *
	 * @since 1.0.0
	 *
	 * @param  string $layout The layout for the product categories.
	 *
	 * @return string         The updated layout for the product categories.
	 */
	public function content_product_cat_layout( $layout ) {
		return $this->get_theme_mod( 'product_cat_layout' );
	}

	/**
	 * Return the category layout for the product categories.
	 *
	 * @since 1.0.0
	 *
	 * @param  string $args The layout for the product categories.
	 *
	 * @return string         The updated layout for the product categories.
	 */
	public function product_button_format( $args ) {
		return $this->get_theme_mod( 'archive_product_button_format' );
	}
}

return new Grimlock_WooCommerce_Archive_Product_Customizer();
