<?php
/**
 * Grimlock_WooCommerce_Navbar_Customizer Class
 *
 * @author  Themosaurus
 * @package grimlock
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock WooCommerce Customizer class for the navbar
 */
class Grimlock_WooCommerce_Navbar_Customizer extends Grimlock_Base_Customizer {
	/**
	 * Setup class.
	 */
	public function __construct() {
		$this->section = 'grimlock_woocommerce_navbar_customizer_section';
		$this->title   = esc_html__( 'Navigation', 'grimlock-woocommerce' );

		add_action( 'after_setup_theme',                                               array( $this, 'add_customizer_fields'               ), 20    );
		add_filter( 'grimlock_woocommerce_navbar_nav_menu_wc_account_displayed',       array( $this, 'nav_menu_wc_account_displayed'       ), 10, 1 );
		add_filter( 'grimlock_woocommerce_navbar_nav_menu_mini_cart_displayed',        array( $this, 'nav_menu_mini_cart_displayed'        ), 10, 1 );
		add_filter( 'grimlock_woocommerce_navbar_nav_menu_mini_cart_type',             array( $this, 'nav_menu_mini_cart_type'             ), 10, 1 );
		add_filter( 'grimlock_woocommerce_navbar_nav_menu_product_search_displayed',   array( $this, 'nav_menu_product_search_displayed'   ), 10, 1 );
		add_filter( 'grimlock_woocommerce_navbar_nav_menu_product_compare_displayed',  array( $this, 'nav_menu_product_compare_displayed'  ), 10, 1 );
		add_filter( 'grimlock_woocommerce_navbar_nav_menu_product_wishlist_displayed', array( $this, 'nav_menu_product_wishlist_displayed' ), 10, 1 );
	}

	/**
	 * Register default values, settings and custom controls for the Theme Customizer.
	 */
	public function add_customizer_fields() {
		$this->defaults = apply_filters( 'grimlock_woocommerce_navbar_customizer_defaults', array(
			'navbar_nav_menu_wc_account_displayed'       => false,
			'navbar_nav_menu_product_search_displayed'   => false,
			'navbar_nav_menu_mini_cart_displayed'        => true,
			'navbar_nav_menu_mini_cart_type'             => 'dropdown',
			'navbar_nav_menu_product_compare_displayed'  => false,
			'navbar_nav_menu_product_wishlist_displayed' => false,
		) );

		$this->add_section();

		$this->add_nav_menu_wc_account_displayed_field(           array( 'priority' => 10 ) );
		if ( class_exists( 'WPCleverWpcas' ) ) {
			$this->add_nav_menu_product_search_displayed_field(   array( 'priority' => 20 ) );
		}
		$this->add_nav_menu_mini_cart_displayed_field(            array( 'priority' => 30 ) );
		$this->add_nav_menu_mini_cart_type_field(                 array( 'priority' => 40 ) );
		if ( class_exists( 'WPCleverWoosc' ) ) {
			$this->add_nav_menu_product_compare_displayed_field(  array( 'priority' => 50 ) );
		}
		if ( class_exists( 'WPCleverWoosw' ) ) {
			$this->add_nav_menu_product_wishlist_displayed_field( array( 'priority' => 60 ) );
		}
	}

	/**
	 * Add a Kirki checkbox field in the Customizer to set whether the "My account" menu is displayed in the navbar
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_nav_menu_wc_account_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki') ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display "My Account" Menu', 'grimlock-woocommerce' ),
				'settings' => 'navbar_nav_menu_wc_account_displayed',
				'default'  => $this->get_default( 'navbar_nav_menu_wc_account_displayed' ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_navbar_customizer_nav_menu_wc_account_displayed_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox field in the Customizer to set whether the product search is displayed in the navbar
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_nav_menu_product_search_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki') ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display Product Search Button', 'grimlock-woocommerce' ),
				'settings' => 'navbar_nav_menu_product_search_displayed',
				'default'  => $this->get_default( 'navbar_nav_menu_product_search_displayed' ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_navbar_customizer_nav_menu_product_search_displayed_field_args', $args ) );
		}
	}
	/**
	 * Add a Kirki checkbox field in the Customizer to set whether the mini cart is displayed in the navbar
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_nav_menu_mini_cart_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki') ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display Mini Cart', 'grimlock-woocommerce' ),
				'settings' => 'navbar_nav_menu_mini_cart_displayed',
				'default'  => $this->get_default( 'navbar_nav_menu_mini_cart_displayed' ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_navbar_customizer_nav_menu_mini_cart_displayed_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki select control to set the mini cart type in the Customizer
	 *
	 * @param array $args
	 */
	protected function add_nav_menu_mini_cart_type_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'select',
				'section'  => $this->section,
				'label'    => esc_html__( 'Mini Cart Type', 'grimlock-woocommerce' ),
				'settings' => 'navbar_nav_menu_mini_cart_type',
				'default'  => $this->get_default( 'navbar_nav_menu_mini_cart_type' ),
				'priority' => 10,
				'choices'  => array(
					'dropdown' => esc_html__( 'Dropdown', 'grimlock-woocommerce' ),
					'drawer'   => esc_html__( 'Drawer', 'grimlock-woocommerce' ),
				),
				'active_callback' => array(
					array(
						'setting'  => 'navbar_nav_menu_mini_cart_displayed',
						'operator' => '==',
						'value'    => true,
					),
				),
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_navbar_customizer_nav_menu_mini_cart_type_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox field in the Customizer to set whether the product compare button is displayed in the navbar
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_nav_menu_product_compare_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki') ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display Compare Button', 'grimlock-woocommerce' ),
				'settings' => 'navbar_nav_menu_product_compare_displayed',
				'default'  => $this->get_default( 'navbar_nav_menu_product_compare_displayed' ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_navbar_customizer_nav_menu_product_compare_displayed_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki checkbox field in the Customizer to set whether the product wishlist button is displayed in the navbar
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_nav_menu_product_wishlist_displayed_field( $args = array() ) {
		if ( class_exists( 'Kirki') ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'checkbox',
				'section'  => $this->section,
				'label'    => esc_html__( 'Display Wishlist Button', 'grimlock-woocommerce' ),
				'settings' => 'navbar_nav_menu_product_wishlist_displayed',
				'default'  => $this->get_default( 'navbar_nav_menu_product_wishlist_displayed' ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_navbar_customizer_nav_menu_product_wishlist_displayed_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki section in the Customizer.
	 *
	 * @param array $args
	 */
	protected function add_section( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			Kirki::add_section( $this->section, apply_filters( "{$this->section}_args", array(
				'title'    => $this->title,
				'priority' => 1,
				'panel'    => 'woocommerce',
			) ) );
		}
	}

	/**
	 * Filter whether the "My Account" link should be displayed in the navbar
	 *
	 * @param bool $displayed
	 *
	 * @return bool
	 */
	public function nav_menu_wc_account_displayed( $displayed ) {
		return ! empty( $this->get_theme_mod( 'navbar_nav_menu_wc_account_displayed' ) );
	}

	/**
	 * Filter whether the product search should be displayed in the navbar
	 *
	 * @param bool $displayed
	 *
	 * @return bool
	 */
	public function nav_menu_product_search_displayed( $displayed ) {
		return ! empty( $this->get_theme_mod( 'navbar_nav_menu_product_search_displayed' ) );
	}

	/**
	 * Filter whether the mini cart should be displayed in the navbar
	 *
	 * @param bool $displayed
	 *
	 * @return bool
	 */
	public function nav_menu_mini_cart_displayed( $displayed ) {
		return ! empty( $this->get_theme_mod( 'navbar_nav_menu_mini_cart_displayed' ) );
	}

	/**
	 * Filter the type of mini cart to use in the navbar
	 *
	 * @param string $type
	 *
	 * @return string
	 */
	public function nav_menu_mini_cart_type( $type ) {
		return $this->get_theme_mod( 'navbar_nav_menu_mini_cart_type' );
	}

	/**
	 * Filter whether the product compare should be displayed in the navbar
	 *
	 * @param bool $displayed
	 *
	 * @return bool
	 */
	public function nav_menu_product_compare_displayed( $displayed ) {
		return ! empty( $this->get_theme_mod( 'navbar_nav_menu_product_compare_displayed' ) );
	}

	/**
	 * Filter whether the product wishlist should be displayed in the navbar
	 *
	 * @param bool $displayed
	 *
	 * @return bool
	 */
	public function nav_menu_product_wishlist_displayed( $displayed ) {
		return ! empty( $this->get_theme_mod( 'navbar_nav_menu_product_wishlist_displayed' ) );
	}
}

return new Grimlock_WooCommerce_Navbar_Customizer();
