<?php
/**
 * Grimlock_WooCommerce_Store_Notice_Customizer Class
 *
 * @author  Themosaurus
 * @package grimlock-woocommerce
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock_WooCommerce_Store_Notice_Customizer class.
 */
class Grimlock_WooCommerce_Store_Notice_Customizer extends Grimlock_Base_Customizer {
	/**
	 * Setup class.
	 */
	public function __construct() {
		$this->section = 'woocommerce_store_notice';

		add_action( 'after_setup_theme', array( $this, 'add_customizer_fields' ), 20 );
	}

	/**
	 * Register default values, settings and custom controls for the Theme Customizer.
	 */
	public function add_customizer_fields() {
		$this->defaults = apply_filters( 'grimlock_global_customizer_defaults', array(
			'woocommerce_store_notice_color'             => '#ffffff',
			'woocommerce_store_notice_background_color'  => GRIMLOCK_GRAY_DARK,
			'woocommerce_store_notice_background_image'  => '',
		) );

		$this->add_color_field(            array( 'priority' => 10 ) );
		$this->add_background_color_field( array( 'priority' => 10 ) );
		$this->add_background_image_field( array( 'priority' => 10 ) );
	}

	/**
	 * Add a Kirki color field to set the background color in the Customizer.
	 *
	 * @param array $args
	 */
	protected function add_background_color_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {

			$output = array( $this->get_css_var_output( 'woocommerce_store_notice_background_color' ) );

			$args = wp_parse_args( $args, array(
				'type'      => 'color',
				'label'     => esc_html__( 'Background color', 'grimlock-woocommerce' ),
				'section'   => $this->section,
				'settings'  => 'woocommerce_store_notice_background_color',
				'default'   => $this->get_default( 'woocommerce_store_notice_background_color' ),
				'choices'   => array(
					'alpha'    => true,
					'palettes' => apply_filters( 'grimlock_color_field_palettes', array() ),
				),
				'priority'  => 10,
				'transport' => 'postMessage',
				'output'    => $output,
				'js_vars'   => $this->to_js_vars( $output ),
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_store_notice_customizer_background_color_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki color field to set the text color in the Customizer.
	 *
	 * @param array $args
	 */
	protected function add_color_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {

			$output = array( $this->get_css_var_output( 'woocommerce_store_notice_color' ) );

			$args = wp_parse_args( $args, array(
				'type'      => 'color',
				'label'     => esc_html__( 'Text color', 'grimlock-woocommerce' ),
				'section'   => $this->section,
				'settings'  => 'woocommerce_store_notice_color',
				'default'   => $this->get_default( 'woocommerce_store_notice_color' ),
				'choices'   => array(
					'alpha'    => true,
					'palettes' => apply_filters( 'grimlock_color_field_palettes', array() ),
				),
				'priority'  => 10,
				'transport' => 'postMessage',
				'output'    => $output,
				'js_vars'   => $this->to_js_vars( $output ),
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_store_notice_customizer_color_field_args', $args ) );
		}
	}

	/**
	 * Add a Kirki image field to set the background image for the region in the Customizer.
	 *
	 * @param array $args
	 * @since 1.0.0
	 */
	protected function add_background_image_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {

			$output = array(
				array_merge( $this->get_css_var_output( 'woocommerce_store_notice_background_image' ), array( 'value_pattern' => 'url("$")' ) )
			);

			$args = wp_parse_args( $args, array(
				'type'      => 'image',
				'section'   => $this->section,
				'label'     => esc_html__( 'Background Image', 'grimlock-woocommerce' ),
				'settings'  => 'woocommerce_store_notice_background_image',
				'default'   => $this->get_default( 'woocommerce_store_notice_background_image' ),
				'priority'  => 10,
				'transport' => 'postMessage',
				'output'    => $output,
				'js_vars'   => $this->to_js_vars( $output ),
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_woocommerce_store_notice_customizer_background_image_field_args', $args ) );
		}
	}

}

return new Grimlock_WooCommerce_Store_Notice_Customizer();
