<?php
/**
 * Grimlock_WooCommerce_Taxonomy_WPC_Brand_Customizer Class
 *
 * @author  Themosaurus
 * @package grimlock-woocommerce
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock Customizer class for the posts page and the archive pages.
 */
class Grimlock_WooCommerce_Taxonomy_WPC_Brand_Customizer {
	/**
	 * Setup class.
	 */
	public function __construct() {
		add_filter( 'grimlock_custom_header_args',                                 array( $this, 'add_custom_header_args' ), 30, 1 );
		add_filter( 'grimlock_woocommerce_archive_product_customizer_is_template', array( $this, 'is_template'            ), 10, 1 );
	}

	/**
	 * @param $default
	 *
	 * @return bool
	 */
	public function is_template( $default = false ) {
		return is_tax( 'wpc-brand' ) || $default;
	}

	/**
	 * Change the title for the Custom Header.
	 *
	 * @param  array $args The array of arguments for the Custom Header.
	 *
	 * @return array       The filtered array of arguments for the Custom Header.
	 */
	public function add_custom_header_args( $args ) {
		if ( $this->is_template() ) {
			$args['title']    = single_term_title( "", false );
			$args['subtitle'] = term_description();

			$brand_id = get_queried_object_id();

			if ( ! empty( $brand_id ) ) {
				$defaults      = apply_filters( 'grimlock_woocommerce_archive_product_customizer_defaults', array( 'archive_product_custom_header_layout' => '6-6-cols-left-reverse', ) );
				$header_layout = get_theme_mod( 'archive_product_custom_header_layout', $defaults['archive_product_custom_header_layout'] );
				$brand_logo    = get_term_meta( $brand_id, 'wpcbr_logo', true );
				$brand_banner  = get_term_meta( $brand_id, 'wpcbr_banner', true );

				if ( ! empty( $brand_logo ) ) {
					$thumbnail_size    = apply_filters( 'grimlock_woocommerce_taxonomy_wpc_brand_customizer_custom_header_thumbnail_size', "thumbnail-{$header_layout}", $header_layout );
					$args['thumbnail'] = wp_get_attachment_image_url( $brand_logo, '6-6-cols-classic' );
					$args['thumbnail_displayed'] = true;
				}

				if ( ! empty( $brand_banner ) ) {
					$background_image_size    = apply_filters( 'grimlock_woocommerce_taxonomy_wpc_brand_customizer_custom_header_background_image_size', 'custom-header', $header_layout );
					$args['background_image'] = wp_get_attachment_image_url( $brand_banner, 'custom-header' );
				}
			}
		}
		return $args;
	}
}

return new Grimlock_WooCommerce_Taxonomy_WPC_Brand_Customizer();
