<?php
/**
 * Grimlock_WooCommerce_Typography_Customizer Class
 *
 * @author  Themosaurus
 * @since   1.0.0
 * @package grimlock
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock WooCommerce Customizer style class.
 */
class Grimlock_WooCommerce_Typography_Customizer {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_filter( 'grimlock_typography_customizer_link_elements',         array( $this, 'add_link_elements'         ), 10, 1 );
		add_filter( 'grimlock_typography_customizer_text_color_elements',   array( $this, 'add_text_color_elements'   ), 10, 1 );
		add_filter( 'grimlock_typography_customizer_text_color_outputs',    array( $this, 'add_text_color_outputs'    ), 10, 1 );
		add_filter( 'grimlock_typography_customizer_heading_font_outputs',  array( $this, 'add_heading_font_outputs'  ), 10, 1 );
		add_filter( 'grimlock_typography_customizer_link_color_elements',   array( $this, 'add_link_color_elements'   ), 10, 1 );
	}

	/**
	 * @param $elements
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function add_link_elements( $elements ) {
		return array_merge( $elements, array(
			'.woocommerce .woocommerce-breadcrumb a',
			'.woocommerce-page .woocommerce-breadcrumb a',
		) );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the link color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the link color.
	 *
	 * @return array           The updated array of CSS selectors for the link color.
	 */
	public function add_link_color_elements( $elements ) {
		return array_merge( $elements, array(
		) );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the text color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the text color.
	 *
	 * @return array           The updated array of CSS selectors for the text color.
	 */
	public function add_text_color_elements( $elements ) {
		return array_merge( $elements, array(
			'.yith-ajaxsearchform-container .autocomplete-suggestions',
		) );
	}

	/**
	 * Add selectors and properties to the CSS rule-set for the text color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $outputs The array of CSS selectors and properties for the text color.
	 *
	 * @return array          The updated array of CSS selectors for the text color.
	 */
	public function add_text_color_outputs( $outputs ) {
		return array_merge( $outputs, array(
			array(
				'element'  => implode( ',', array(
					'.woocommerce div.quantity.buttons_added .minus',
					'.woocommerce div.quantity.buttons_added .plus',
					'.woocommerce-page div.quantity.buttons_added .minus',
					'.woocommerce-page div.quantity.buttons_added .plus',
				) ),
				'property' => 'border-color',
			),
		) );
	}

	/**
	 * Add selectors and properties to the CSS rule-set for the heading font.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $outputs The array of CSS selectors and properties for the heading font.
	 *
	 * @return array          The updated array of CSS selectors for the heading font.
	 */
	public function add_heading_font_outputs( $outputs ) {

		$elements_headings = array(
			'.woocommerce ul.products li.product .price',
			'.woocommerce-page ul.products li.product .price',
			'.woocommerce div.product span.price',
			'.woocommerce div.product p.price',
			'.woocommerce-page div.product span.price',
			'.woocommerce-page div.product p.price',
			'.product_list_widget li del',
			'.product_list_widget li ins',
			'.product_list_widget li .woocommerce-Price-amount',
			'.woocommerce ul.product_list_widget li .product-title',
		);

		return array_merge( $outputs, array(
			array(
				'element'  => implode( ',', $elements_headings ),
				'property' => 'font-family',
				'choice'   => 'font-family',
			),
			array(
				'element'  => implode( ',', $elements_headings ),
				'property' => 'text-transform',
				'choice'   => 'text-transform',
			),
			array(
				'element'  => implode( ',', $elements_headings ),
				'property' => 'font-weight',
				'choice'   => 'font-weight',
			),
			array(
				'element'  => implode( ',', $elements_headings ),
				'property' => 'font-style',
				'choice'   => 'font-style',
			),
		) );
	}
}

return new Grimlock_WooCommerce_Typography_Customizer();
