<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.6.0
 */

// @codingStandardsIgnoreFile
// Allow plugin text domain in theme and unescaped template tags.

defined( 'ABSPATH' ) || exit;

global $product;

// Ensure visibility.
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}

$products_args = apply_filters( 'grimlock_woocommerce_product_args', array() );

if ( empty( $products_args['remove_li'] ) ) : ?>
	<li <?php wc_product_class( '', $product ); ?>>
<?php endif; ?>

	<div class="card product__card">

		<div class="product__card-header card-media">
			<?php
			/**
			 * Hook: woocommerce_before_shop_loop_item.
			 *
			 * @hooked woocommerce_template_loop_product_link_open - 10
			 */
			do_action( 'woocommerce_before_shop_loop_item' ); ?>

			<div class="post-thumbnail">
				<?php
				woocommerce_template_loop_product_link_open();

				grimlock_woocommerce_product_out_of_stock( $products_args );

				/**
				 * Hook: woocommerce_before_shop_loop_item_title.
				 *
				 * @hooked woocommerce_show_product_loop_sale_flash - 10
				 * @hooked woocommerce_template_loop_product_thumbnail - 10
				 */
				do_action( 'woocommerce_before_shop_loop_item_title' );

				woocommerce_template_loop_product_link_close();
				?>
			</div><!-- .post-thumbnail -->

			<?php if ( ! empty( $products_args['product_add_to_cart_displayed'] ) && apply_filters( 'grimlock_woocommerce_product_button_format', 'icon' ) !== 'text' ) :
				grimlock_woocommerce_product_after_shop_loop_item();
			endif; ?>

		</div><!-- .product__card-header -->

		<div class="card-body">

			<?php grimlock_woocommerce_category_list( $products_args ); ?>

			<div class="entry-header">
				<?php
				woocommerce_template_loop_product_link_open();

				/**
				 * Hook: woocommerce_shop_loop_item_title.
				 *
				 * @hooked woocommerce_template_loop_product_title - 10
				 */
				do_action( 'woocommerce_shop_loop_item_title' );

				woocommerce_template_loop_product_link_close();

				/**
				 * Hook: woocommerce_after_shop_loop_item_title.
				 *
				 * @hooked woocommerce_template_loop_rating - 5
				 * @hooked woocommerce_template_loop_price - 10
				 */
				do_action( 'woocommerce_after_shop_loop_item_title' ); ?>
			</div><!-- .entry-header -->

			<?php grimlock_post_excerpt( $products_args ); ?>

			<?php if ( class_exists( 'WPCleverWpcvs' ) && get_option( 'wpcvs_archive_enable', 'no' ) === 'yes' ) {
				if ( get_option( 'wpcvs_archive_position', 'before' ) === 'before' ) {
					// Hack to call non-static method that could be static in WPCleverWpcvs class
					$wpcvs_reflection = new ReflectionClass( 'WPCleverWpcvs' );
					$wpcvs_obj = $wpcvs_reflection->newInstanceWithoutConstructor();
					$wpcvs_obj->archive();
				}
			} ?>

			<?php if ( ! empty( $products_args['product_add_to_cart_displayed'] ) && apply_filters( 'grimlock_woocommerce_product_button_format', 'icon' ) === 'text' ) :
				grimlock_woocommerce_product_after_shop_loop_item();
			endif; ?>

			<?php if ( ! empty( $products_args['product_add_to_cart_displayed'] ) && apply_filters( 'grimlock_woocommerce_product_button_format', 'icon' ) === 'icon-main-button' ) :
				woocommerce_template_loop_add_to_cart();
			endif; ?>

			<?php if ( class_exists( 'WPCleverWpcvs' ) && get_option( 'wpcvs_archive_enable', 'no' ) === 'yes' ) {
				if ( get_option( 'wpcvs_archive_position', 'before' ) === 'after' ) {
					// Hack to call non-static method that could be static in WPCleverWpcvs class
					$wpcvs_reflection = new ReflectionClass( 'WPCleverWpcvs' );
					$wpcvs_obj = $wpcvs_reflection->newInstanceWithoutConstructor();
					$wpcvs_obj->archive();
				}
			} ?>

		</div><!-- .card-body -->

	</div><!-- .card -->

<?php if ( empty( $products_args['remove_li'] ) ) : ?>
	</li><!-- .product -->
<?php endif; ?>
